From 67f37b440bdc89a872932a92f1920ea3947e391c Mon Sep 17 00:00:00 2001
From: lukeIam <2lukeiam@gmail.com>
Date: Sun, 20 Dec 2015 13:48:19 +0100
Subject: [PATCH] Changed PitchTracker build to static linking to get rid of
runtime version conficts (size increase is not huge: 52KB -> 267KB)
---
PitchTracker/PitchTracker.vcxproj | 8 ++++++--
1 file changed, 6 insertions(+), 2 deletions(-)
diff --git a/PitchTracker/PitchTracker.vcxproj b/PitchTracker/PitchTracker.vcxproj
index b5fb8ca0..77d7b228 100644
--- a/PitchTracker/PitchTracker.vcxproj
+++ b/PitchTracker/PitchTracker.vcxproj
@@ -109,6 +109,7 @@
true
Fast
false
+ MultiThreadedDebug
Windows
@@ -127,6 +128,7 @@
true
Fast
false
+ MultiThreadedDebug
Windows
@@ -148,6 +150,7 @@
Speed
Fast
false
+ MultiThreaded
Windows
@@ -170,6 +173,7 @@
true
Speed
Fast
+ MultiThreaded
Windows
@@ -212,6 +216,6 @@
-
+
-
+
\ No newline at end of file